package results;

/** Generic constraints for a contest */
public final class Constraints
{
  /** Name of the contest */
  public static final String CONTEST_TITLE = "ContestName";
  /** Maximum points awarded for each contestant */
  public static final int MAX_POINTS = 30;

  /** Minimum frequences (negative=percentage of all scores, other=amount) */
  public final int min[] = new int[MAX_POINTS + 1];
  /** Maximum frequences (negative=percentage of all scores, other=amount) */
  public final int max[] = new int[MAX_POINTS + 1];
  /** Limits of rectification rounds (optional).  The elements of the array
  should be non-negative integers in decreasing order.  The rectified points
  of a judge are obtained by correcting them towards the average points awarded
  by all judges, so that the difference is within the rectification limit. */
  public int rect[] = new int[] { 3, 2 }; // default for backward compatibility

  /** Constructor */
  public Constraints ()
  {
    // Set up most relaxed frequences (everything can be 0 to 100 percent)
    for (int i = max.length; i-- > 0; )
      max[i] = -100;
  }

  /** Compute a histogram of points
   * @param points	points given by a judge
   * @return		a histogram (amounts of points indexed by points)
   */
  public static int[] histogram (int[] points)
  {
    int histogram[] = new int[MAX_POINTS + 1];
    for (int i = points.length; i-- > 0; )
      if (points[i] <= MAX_POINTS)
	histogram[points[i]]++;
    return histogram;
  }

  /** Compute a bitmap of points given too frequently by a judge */
  public boolean[] getFrequent (int[] points)
  {
    final int histogram[] = histogram (points);
    boolean freq[] = new boolean[MAX_POINTS + 1];
    // Determine which points are too frequent
    for (int i = MAX_POINTS + 1; i-- > 0; )
      freq[i] = histogram[i] > (max[i] < 0
				? (max[i] * points.length / -100)
				: max[i]);
    return freq;
  }

  public boolean[] getInfrequent (int[] points)
  {
    final int histogram[] = histogram (points);
    boolean freq[] = new boolean[MAX_POINTS + 1];
    // Determine which points are too frequent
    for (int i = MAX_POINTS + 1; i-- > 0; )
      freq[i] = histogram[i] < (min[i] < 0
				? (min[i] * points.length / -100)
				: min[i]);
    return freq;
  }
}
