package results;

/** An interface for reporting errors in contests */
public interface ErrorReporter
{
  /** Report a numberless mirror
   * @param mirror	a mirror with no assigned number
   */
  public void reportMissingNumber (Mirror mirror);
  /** Report a repeated mirror number
   * @param m1		first mirror with the number
   * @param m2		second mirror with the number
   */
  public void reportRepeatedNumber (Mirror m1, Mirror m2);
  /** Report that a judge has not given any points to a mirror
   * @param mirror	the mirror
   * @param judge	the judge
   */
  public void reportMissingPoints (Mirror mirror, Judge judge);
  /** Report that a score has been given too frequently in a contest
   * @param points	the score given
   * @param judge	the judge
   * @param contest	the contest
   */
  public void reportFrequent (int points,
			      Judge judge,
			      Contest contest);
  /** Report that a score has been given too infrequently in a contest
   * @param points	the score given
   * @param judge	the judge
   * @param contest	the contest
   */
  public void reportInfrequent (int points,
				Judge judge,
				Contest contest);
}
