package results;

import java.util.Collection;
import java.util.Enumeration;
import java.util.Locale;
import java.util.ResourceBundle;
import java.util.TreeMap;

/** Collection of penalty reasons */
public final class Reasons
{
  /** Map from reason codes to explanations */
  private TreeMap reasons;
  /** Constructor
   * @param locale	the locale for the reason explanations
   */
  public Reasons (Locale locale)
  {
    setLocale (locale);
  }
  /** Set the locale
   * @param locale	the desired locale
   */
  public void setLocale (Locale locale)
  {
    reasons = new TreeMap ();
    final ResourceBundle bundle = ResourceBundle.getBundle ("penalty", locale);
    for (Enumeration en = bundle.getKeys (); en.hasMoreElements (); ) {
      String code = (String) en.nextElement ();
      if (code.length () == 1)
	reasons.put (code,
		     new Reason (code.charAt (0), bundle.getString (code)));
    }
  }

  /** Get a reason by code
   * @param code	the reason code
   * @return		the Reason object, or null
   */
  public Reason get (String code)
  {
    return (Reason) reasons.get (code);
  }

  /** Get the stored countries */
  public Collection values ()
  {
    return reasons.values ();
  }
}
