package results.ui;

import results.Constraints;
import results.Series;

import java.util.Locale;
import javax.swing.JLabel;
import javax.swing.JTable;
import javax.swing.event.TableModelEvent;
import javax.swing.table.AbstractTableModel;
import javax.swing.table.DefaultTableCellRenderer;
import javax.swing.table.TableColumnModel;

/** Table for viewing and editing constraint data */
final class ConstraintTable
  extends JTable
{
  /** The series dialog containing this table */
  private SeriesDialog parent;
  /** The score cell renderer */
  private DefaultTableCellRenderer rscore;
  /** The minimum amount cell renderer */
  private DefaultTableCellRenderer rmin;
  /** The maximum amount cell renderer */
  private DefaultTableCellRenderer rmax;

  /** The score */
  private static final int COLUMN_SCORE = 0;
  /** The minimum amount */
  private static final int COLUMN_MIN = 1;
  /** The maximum amount */
  private static final int COLUMN_MAX = 2;

  /** Constructor
   * @param dialog	the containing series dialog
   */
  ConstraintTable (SeriesDialog dialog)
  {
    parent = dialog;
    setModel (new AbstractTableModel ()
      {
	public int getColumnCount () { return 3; }
	public int getRowCount () { return Constraints.MAX_POINTS + 1; }
	public boolean isCellEditable (int row, int col) { return col > 0; }
	public Class getColumnClass (int col) {
	  return col > 0 ? String.class : Integer.class;
	}
	public Object getValueAt (int row, int col) {
	  int value;
	  switch (col) {
	  case COLUMN_SCORE:
	    return new Integer (row);
	  case COLUMN_MIN:
	    value = parent.series.constraints.min[row];
	    return value < 0
	      ? new Integer (-value).toString () + "%"
	      : new Integer (value).toString ();
	  case COLUMN_MAX:
	    value = parent.series.constraints.max[row];
	    return value < 0
	      ? new Integer (-value).toString () + "%"
	      : new Integer (value).toString ();
	  }
	  return null;
	}
	public void setValueAt (Object value, int row, int col) {
	  String v = (String) value;
	  if (v.indexOf ('-') >= 0)
	    return;
	  int percent = v.indexOf ('%');
	  try {
	    int val = percent > 0
	      ? -Integer.parseInt (v.substring (0, percent))
	      : Integer.parseInt (v);
	    if (val < -100) val = -100;
	    switch (col) {
	    case COLUMN_MIN:
	      if (val != parent.series.constraints.min[row]) {
		parent.series.constraints.min[row] = val;
		parent.series.flagModified ();
	      }
	      break;
	    case COLUMN_MAX:
	      if (val != parent.series.constraints.max[row]) {
		parent.series.constraints.max[row] = val;
		parent.series.flagModified ();
	      }
	      break;
	    }
	  }
	  catch (Exception e) {
	  }
	}
	public String getColumnName (int col) {
	  switch (col) {
	  case COLUMN_SCORE:
	    return parent.translator.lookup ("constraints.nScore");
	  case COLUMN_MIN:
	    return parent.translator.lookup ("constraints.nMin");
	  case COLUMN_MAX:
	    return parent.translator.lookup ("constraints.nMax");
	  }
	  return null;
	}
      });
    rscore = new DefaultTableCellRenderer ();
    rmin = new DefaultTableCellRenderer ();
    rmax = new DefaultTableCellRenderer ();
    rscore.setHorizontalAlignment (JLabel.RIGHT);
    rmin.setHorizontalAlignment (JLabel.RIGHT);
    rmax.setHorizontalAlignment (JLabel.RIGHT);
  }

  public void setLocale (Locale locale)
  {
    super.setLocale (locale);
    rscore.setToolTipText (parent.translator.lookup ("constraints.tScore"));
    rmin.setToolTipText (parent.translator.lookup ("constraints.tMin"));
    rmax.setToolTipText (parent.translator.lookup ("constraints.tMax"));
    tableChanged (new TableModelEvent
      (getModel (), TableModelEvent.HEADER_ROW));
  }

  /** Invoked when the table model changes */
  public void tableChanged (TableModelEvent e)
  {
    super.tableChanged (e);
    if (rscore == null || rmin == null || rmax == null);
    else if (e == null || e.getFirstRow () == TableModelEvent.HEADER_ROW) {
      TableColumnModel cols = getColumnModel ();
      cols.getColumn (COLUMN_SCORE).setCellRenderer (rscore);
      cols.getColumn (COLUMN_MIN).setCellRenderer (rmin);
      cols.getColumn (COLUMN_MAX).setCellRenderer (rmax);
    }
  }
}
