package results.ui;

import results.Countries;
import results.Country;

import java.text.Collator;
import java.util.Iterator;
import java.util.TreeMap;
import java.util.Locale;
import javax.swing.JComboBox;

/** A combo box for picking a country code */
public final class CountryBox
  extends JComboBox
{
  /** The countries displayed in this box */
  private Countries countries;
  /** The default country for new data */
  private Country country;

  /** Constructor
   * @param countries	the countries this box displays
   */
  public CountryBox (Countries countries) {
    this.countries = countries;
    updateCountries ();
  }

  /** Rebuild the list */
  public void updateCountries () {
    TreeMap map = new TreeMap (Collator.getInstance (countries.getLocale ()));
    Iterator i;
    for (i = countries.values ().iterator (); i.hasNext (); ) {
      Country c = (Country) i.next ();
      map.put (c.name, c);
    }
    removeAllItems ();
    for (i = map.values ().iterator (); i.hasNext (); )
      addItem (i.next ());
  }

  /** Get the selected country */
  public Object getSelectedItem ()
  {
    Country c = (Country) super.getSelectedItem ();
    if (c == null)
      return country == null ? (Country) getItemAt (0) : country;
    else
      return country = c;
  }

  /** Get the default country */
  public Country getDefault ()
  {
    return (Country) getSelectedItem ();
  }
}
