package results.ui;

import results.Contest;
import results.ErrorReporter;
import results.Judge;
import results.Mirror;

import java.text.MessageFormat;
import java.util.Locale;
import java.util.ResourceBundle;
import javax.swing.JDialog;
import javax.swing.JTextArea;

/** A dialog for reporting errors */
final class ErrorDialog
  extends JDialog
  implements ErrorReporter
{
  /** The error message resource bundle */
  private ResourceBundle bundle;
  /** The message format */
  private MessageFormat mf;
  /** The text area for the error messages */
  private JTextArea area;
  /** Flag: have any errors been reported? */
  public boolean reported = false;

  /** Constructor
   * @param dialog	the parent dialog
   */
  ErrorDialog (SeriesDialog dialog)
  {
    super (dialog);
    final Locale locale = dialog.getLocale ();
    bundle = ResourceBundle.getBundle ("errors", locale);
    (mf = new MessageFormat (bundle.getString ("title"))).setLocale (locale);
    setTitle (mf.format (new Object[] { dialog.series.getName ()}));
    getContentPane ().add (area = new JTextArea ());
    area.setEditable (false);
    area.setColumns (60);
    area.setRows (15);
    pack ();
  }

  /** Report a numberless mirror
   * @param mirror	a mirror with no assigned number
   */
  public void reportMissingNumber (Mirror mirror)
  {
    mf.applyPattern (bundle.getString ("mirror.number"));
    area.append (mf.format (new Object[]
      { mirror.getContest (), mirror.getCompetitor () }) + "\n");
    reported = true;
  }

  /** Report a repeated mirror number
   * @param m1		first mirror with the number
   * @param m2		second mirror with the number
   */
  public void reportRepeatedNumber (Mirror m1, Mirror m2)
  {
    mf.applyPattern (bundle.getString ("mirror.repeated"));
    area.append (mf.format (new Object[] { m1.getContest (), m1.getNumber (),
					   m1.getCompetitor (),
					   m2.getCompetitor () }) + "\n");
    reported = true;
  }

  /** Report that a judge has not given any points to a mirror
   * @param mirror	the mirror
   * @param judge	the judge
   */
  public void reportMissingPoints (Mirror mirror, Judge judge)
  {
    mf.applyPattern (bundle.getString ("mirror.points"));
    area.append (mf.format (new Object[]
      { mirror.getContest (), judge.getName (), mirror.getCompetitor () }) +
		 "\n");
    reported = true;
  }

  /** Report that a score has been given too frequently in a contest
   * @param points	the score given
   * @param judge	the judge
   * @param contest	the contest
   */
  public void reportFrequent (int points,
			      Judge judge,
			      Contest contest)
  {
    mf.applyPattern (bundle.getString ("mirror.frequent"));
    area.append (mf.format (new Object[]
      { contest, judge.getName (), new Integer (points) }) + "\n");
    reported = true;
  }

  /** Report that a score has been given too infrequently in a contest
   * @param points	the score given
   * @param judge	the judge
   * @param contest	the contest
   */
  public void reportInfrequent (int points,
				Judge judge,
				Contest contest)
  {
    mf.applyPattern (bundle.getString ("mirror.infrequent"));
    area.append (mf.format (new Object[]
      { contest, judge.getName (), new Integer (points) }) + "\n");
    reported = true;
  }
}
