package results.ui;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.Locale;

import results.Series;

public final class Main
{
  public static void main (String args[])
  {
    boolean gotFiles = false;
    boolean ignoreOpts = false;
    boolean dumpHTML = false;
    ErrorDialog reporter = null;

    for (int i = 0; i < args.length; i++) {
      if (!ignoreOpts && args[i].startsWith ("-")) {
	if (args[i].equals ("--"))
	  ignoreOpts = true;
	else if (args[i].equals ("--help")) {
	  /* TODO: improve this */
	  System.err.println ("Usage: results [options] file.pts ...");
	  System.err.println ("Options: --help, --html, --");
	}
	else if (args[i].equals ("--html"))
	  dumpHTML = true;
	else
	  System.err.println ("Ignoring unknown option " + args[i]);
	continue;
      }

      Series series = new Series (Locale.getDefault ());
      series.setName (args[i]);
      try {
	series.read (new File (args[i]));
	SeriesDialog dialog = new SeriesDialog (series);
	gotFiles = true;
	if (dumpHTML && dialog.generateHTML ())
	  dialog.closeNoExit ();
      }
      catch (FileNotFoundException fe) {
	System.err.println ("File not found: " + fe.getMessage ());
      }
      catch (IOException ioe) {
	System.err.println (ioe.getMessage ());
      }
    }

    if (!gotFiles)
      new SeriesDialog (new Series (Locale.getDefault ()));
    else if (SeriesDialog.dialogs.isEmpty ())
      System.exit (0);
  }
}
