package results.ui;

import java.awt.Container;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Frame;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JTextField;
import javax.swing.event.DocumentEvent;
import javax.swing.event.DocumentListener;

/** A dialog for entering a base for random mirror numbers */
public final class RandomDialog
  extends JDialog
  implements ActionListener, DocumentListener
{
  /** The value entered by the user (null if the dialog was canceled) */
  public Integer value = new Integer (1);
  /** The text field for the mirror number */
  private JTextField text;
  /** The "ok" button */
  private JButton ok;
  /** The "cancel" button */
  private JButton cancel;

  /** Constructor
   * @param dialog	the containing series dialog
   * @param title	the title of the dialog window
   */
  public RandomDialog (SeriesDialog dialog, String title)
  {
    super ((Frame) null, title, true);
    setDefaultCloseOperation (DISPOSE_ON_CLOSE);
    Container content = getContentPane ();
    GridBagLayout layout = new GridBagLayout ();
    GridBagConstraints c = new GridBagConstraints ();
    c.fill = GridBagConstraints.BOTH;
    content.setLayout (layout);

    JLabel label =
      new JLabel (dialog.translator.lookup ("mirror.random.first"));
    c.gridwidth = GridBagConstraints.RELATIVE;
    layout.setConstraints (label, c);
    content.add (label);

    c.gridwidth = GridBagConstraints.REMAINDER;
    layout.setConstraints (text = new JTextField (value.toString (), 3), c);
    content.add (text);
    text.setHorizontalAlignment (JTextField.RIGHT);
    text.getDocument ().addDocumentListener (this);

    c.gridwidth = GridBagConstraints.RELATIVE;
    layout.setConstraints
      (ok = new JButton (dialog.translator.lookup ("mirror.random.ok")), c);
    content.add (ok);
    getRootPane ().setDefaultButton (ok);
    ok.addActionListener (this);

    c.gridwidth = GridBagConstraints.REMAINDER;
    layout.setConstraints
      (cancel = new JButton (dialog.translator.lookup ("cancel")), c);
    content.add (cancel);
    cancel.addActionListener (this);

    pack ();
    setVisible (true);
  }

  /** A button was clicked */
  public void actionPerformed (ActionEvent e)
  {
    final Object src = e.getSource ();
    if (src == cancel)
      value = null;
    setVisible (false);
    dispose ();
  }

  /** The mirror number was changed */
  public void changedUpdate (DocumentEvent e) { updateValue (); }
  /** Part of the mirror number was inserted */
  public void insertUpdate (DocumentEvent e) { updateValue (); }
  /** Part of the mirror number was removed */
  public void removeUpdate (DocumentEvent e) { updateValue (); }

  /** The mirror number was changed */
  private void updateValue ()
  {
    try {
      int num = Integer.parseInt (text.getText ());
      value = num < 1 ? null : new Integer (num);
    }
    catch (NumberFormatException ne) {
      value = null;
    }
    ok.setEnabled (value != null);
  }
}
