package results.ui;

import results.Reasons;
import results.Reason;

import java.text.Collator;
import java.util.Iterator;
import java.util.TreeMap;
import java.util.Locale;
import javax.swing.JComboBox;

/** A combo box for picking a reason code */
public final class ReasonBox
  extends JComboBox
{
  /** The locale */
  private Locale locale;
  /** The reasons displayed in this box */
  private Reasons reasons;
  /** The default reason for new data */
  private Reason reason;

  /** Constructor */
  public ReasonBox () {
    this.reasons = new Reasons (locale = Locale.getDefault ());
    updateReasons ();
  }

  /** Rebuild the list */
  public void updateReasons () {
    TreeMap map = new TreeMap (Collator.getInstance (locale));
    Iterator i;
    for (i = reasons.values ().iterator (); i.hasNext (); ) {
      Reason r = (Reason) i.next ();
      map.put (r.toString (), r);
    }
    removeAllItems ();
    addItem (Reason.empty);
    for (i = map.values ().iterator (); i.hasNext (); )
      addItem (i.next ());
  }

  /** Set the locale */
  public void setLocale (Locale locale) {
    reasons.setLocale (this.locale = locale);
    updateReasons ();
  }

  /** Get the selected reason */
  public Object getSelectedItem ()
  {
    Reason r = (Reason) super.getSelectedItem ();
    if (r == null)
      return reason == null ? (Reason) getItemAt (0) : reason;
    else
      return reason = r;
  }

  /** Get the default reason */
  public Reason getDefault ()
  {
    Reason r = (Reason) getSelectedItem ();
    return r == Reason.empty ? (Reason) getItemAt (1) : r;
  }

  /** Get a reason corresponding to a code */
  public Reason getReason (char code)
  {
    return code == 0 ? null : reasons.get ((new Character (code)).toString ());
  }
}
