package results.ui;

import results.Constraints;
import results.Series;

import java.util.Locale;
import javax.swing.JLabel;
import javax.swing.JTable;
import javax.swing.event.TableModelEvent;
import javax.swing.table.AbstractTableModel;
import javax.swing.table.DefaultTableCellRenderer;
import javax.swing.table.TableColumnModel;

/** Table for viewing and editing rectification limits */
final class RectificationTable
  extends JTable
{
  /** The series dialog containing this table */
  private SeriesDialog parent;
  /** The limit cell renderer */
  private DefaultTableCellRenderer rlimit;

  /** Constructor
   * @param dialog	the containing series dialog
   */
  RectificationTable (SeriesDialog dialog)
  {
    parent = dialog;
    setModel (new AbstractTableModel ()
      {
	public int getColumnCount () { return 1; }
	public int getRowCount () {
	  if (parent.series.constraints.rect == null)
	    return 1;
	  return parent.series.constraints.rect.length + 1;
	}
	public boolean isCellEditable (int row, int col) { return true; }
	public Class getColumnClass (int col) {
	  return Integer.class;
	}
	public Object getValueAt (int row, int col) {
	  if (col != 0)
	    return null;
	  if (parent.series.constraints.rect == null ||
	      row >= parent.series.constraints.rect.length)
	    return "";
	  return new Integer (parent.series.constraints.rect[row]);
	}
	public void setValueAt (Object value, int row, int col) {
	  if (col != 0)
	    return;
	  int val = -1;
	  int rect[] = parent.series.constraints.rect;
	  try {
	    val = Integer.parseInt (value.toString ());
	  }
	  catch (Exception e) {}

	  if (value != null && val < 0) {
	    parent.warn ("rectification.limit.nonnegative", value.toString ());
	    return;
	  }

	  if (rect == null && value == null)
	    return;

	  parent.series.flagModified ();

	  if (rect == null)
	    rect = parent.series.constraints.rect = new int[row + 1];

	  if (row < rect.length) {
	    /* editing or removing an existing row */
	    if (value != null)
	      rect[row] = val;
	    else if (rect.length == 1)
	      parent.series.constraints.rect = null; /* remove last row */
	    else {
	      /* remove a row */
	      int newrect[] = new int[rect.length - 1];
	      /* copy preceding rows */
	      System.arraycopy (rect, 0, newrect, 0, row);
	      /* copy successive rows */
	      System.arraycopy (rect, row + 1, newrect, row,
				newrect.length - row);
	      parent.series.constraints.rect = newrect;
	      tableChanged
		(new TableModelEvent (this, row, row,
				      TableModelEvent.ALL_COLUMNS,
				      TableModelEvent.DELETE));
	    }
	  }
	  else if (value != null) {
	    /* add a row */
	    int newrect[] = new int[row + 1];
	    System.arraycopy (rect, 0, newrect, 0, rect.length);
	    newrect[row] = val;
	    parent.series.constraints.rect = newrect;
	    tableChanged
	      (new TableModelEvent (this, row, row,
				    TableModelEvent.ALL_COLUMNS,
				    TableModelEvent.INSERT));
	  }
	  parent.series.flagContestsModified ();
	}
	public String getColumnName (int col) {
	  switch (col) {
	  case 0:
	    return parent.translator.lookup ("rectification.nLimit");
	  }
	  return null;
	}
      });
    rlimit = new DefaultTableCellRenderer ();
    rlimit.setHorizontalAlignment (JLabel.RIGHT);
  }

  public void setLocale (Locale locale)
  {
    super.setLocale (locale);
    rlimit.setToolTipText (parent.translator.lookup ("rectification.tLimit"));
    tableChanged (new TableModelEvent
      (getModel (), TableModelEvent.HEADER_ROW));
  }

  /** Invoked when the table model changes */
  public void tableChanged (TableModelEvent e)
  {
    super.tableChanged (e);
    if (rlimit == null);
    else if (e == null || e.getFirstRow () == TableModelEvent.HEADER_ROW)
      getColumnModel ().getColumn (0).setCellRenderer (rlimit);
  }
}
